@@ -16,8 +16,9 @@ def test_series_raw_oah():
     qpi = ds.get_qpimage(0)
     assert np.allclose(
         qpi.pha[100:104, 140:142].flatten(),
-        [[3.49996114, 3.52319789, 3.5404067, 3.56799173,
-          3.55650926, 3.58146381, 3.60143375, 3.61734581]],
+        [[4.22381783, 4.25115347, 4.27171421, 4.30390024,
+          4.29087162, 4.31994677, 4.34381723, 4.36178589]
+        ],
         rtol=0,
         atol=1e-7
     )
